@@ -48,7 +48,7 @@ class KeycloakEnvironment():
         self.keycloak_admin_auth_user = os.environ['KEYCLOAK_ADMIN_AUTH_USER'] if 'KEYCLOAK_ADMIN_AUTH_USER' in os.environ else self.defaultAdminAuthUser
         self.keycloak_admin_auth_password = os.environ['KEYCLOAK_ADMIN_AUTH_PASSWORD'] if 'KEYCLOAK_ADMIN_AUTH_PASSWORD' in os.environ else self.defaultAdminAuthPassword
         self.keycloak_admin_auth_realm = os.environ['KEYCLOAK_ADMIN_AUTH_REALM'] if 'KEYCLOAK_ADMIN_AUTH_REALM' in os.environ else self.defaultAdminAuthRealm
-        self.validate_certs = os.environ['VALIDATE_CERTS'] if 'VALIDATE_CERTS' in os.environ else self.defaultValidateCert
+        self.validate_certs = bool(strtobool(os.environ['VALIDATE_CERTS'])) if 'VALIDATE_CERTS' in os.environ else self.defaultValidateCert
         self.kc = self.init_keycloak_api()
 
     def init_keycloak_api(self):
